import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import IconButton from '@sinoui/core/IconButton';
import Popper from '@sinoui/core/Popper';
import useClickAwayListener from '@sinoui/core/useClickAwayListener';
import React, { useCallback, useRef, useState } from 'react';
import { SketchPicker } from 'react-color';
import { useDispatch, useSelector } from 'react-redux';
import styled from 'styled-components';
import { ActionType } from '../../reducer';
import getAllSelectedCells from '../../utils/getAllSelectedCells';
import BgColorIcon from './BgColorIcon';
const StyledIconButton = styled(IconButton) `
  flex-direction: column;
  border-radius: 0;

  .sinoui-svg-icon {
    font-size: 18px;
  }
`;
const ColorWrapper = styled.div `
  background: #fff;
  box-shadow: 0 0 0 1px rgba(0, 0, 0, 0.1);
  cursor: pointer;
  width: 20px;
`;
const ColorPanel = styled.div `
  width: 100%;
  height: 2px;
  background: ${({ color }) => color};
`;
const PickerPanelWrapper = styled.div `
  position: absolute;
  z-index: 2;
`;
/**
 * 填充颜色选择器
 *
 * @param root0
 * @param root0.selectedRange
 * @param root0.disabled
 * @returns
 */
function BgColorPickerButton({ selectedRange, disabled, }) {
    const anchorEl = useRef(null);
    const popperRef = useRef(null);
    const [open, setOpen] = useState(false);
    const [color, setColor] = useState('#F17013');
    const dispatch = useDispatch();
    const merges = useSelector((state) => state.present.merges);
    const handleMouseDown = (event) => {
        event.preventDefault();
        setOpen(!open);
    };
    const handleClose = () => {
        setOpen(false);
    };
    const setTextColor = useCallback((selectedColor) => {
        if (!selectedRange) {
            return;
        }
        const selectedCells = getAllSelectedCells(selectedRange, merges);
        dispatch({
            type: ActionType.SET_CELLS_STYLE,
            payload: {
                cells: selectedCells,
                style: { backgroundColor: selectedColor },
            },
        });
    }, [dispatch, merges, selectedRange]);
    const handleChange = (colorInfo) => {
        setColor(colorInfo.hex);
        setTextColor(colorInfo.hex);
        handleClose();
    };
    useClickAwayListener([anchorEl, popperRef], handleClose);
    return (_jsxs(_Fragment, { children: [_jsxs(StyledIconButton, { dense: true, ref: anchorEl, onMouseDown: handleMouseDown, disabled: disabled, children: [_jsx(BgColorIcon, {}), _jsx(ColorWrapper, { children: _jsx(ColorPanel, { color: color }) })] }), _jsx(Popper, { open: open, referenceElement: anchorEl, placement: "bottom-start", ref: popperRef, children: _jsx(PickerPanelWrapper, { children: _jsx(SketchPicker, { color: color, onChange: handleChange }) }) })] }));
}
export default React.memo(BgColorPickerButton);
