import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/* eslint-disable react/display-name */
import IconButton from '@sinoui/core/IconButton';
import Menu, { MenuListItem } from '@sinoui/core/Menu';
import Popper from '@sinoui/core/Popper';
import useClickAwayListener from '@sinoui/core/useClickAwayListener';
import BorderAll from '@sinoui/icons/BorderAll';
import BorderBottom from '@sinoui/icons/BorderBottom';
import BorderClear from '@sinoui/icons/BorderClear';
import BorderHorizontal from '@sinoui/icons/BorderHorizontal';
import BorderInner from '@sinoui/icons/BorderInner';
import BorderLeft from '@sinoui/icons/BorderLeft';
import BorderOuter from '@sinoui/icons/BorderOuter';
import BorderRight from '@sinoui/icons/BorderRight';
import BorderTop from '@sinoui/icons/BorderTop';
import BorderVertical from '@sinoui/icons/BorderVertical';
import Edit from '@sinoui/icons/Edit';
import PowerInput from '@sinoui/icons/PowerInput';
import { useMemo, useRef, useState } from 'react';
import { SketchPicker } from 'react-color';
import { useDispatch, useSelector } from 'react-redux';
import styled from 'styled-components';
import { BorderType, SECOND_LEVEL_MENU } from '../../constants';
import { setCellsBorderStyle } from '../../reducer';
import Line from './Line';
const Layout = styled.div `
  width: 200px;
  display: flex;
  background: #fff;
  box-shadow: 0px 2px 10px #999999;
`;
const BorderTypeWrapper = styled.div `
  flex: 5;
  display: flex;
  flex-wrap: wrap;
`;
const BorderStyleWrapper = styled.div `
  flex: 1;
  border-left: 1px solid #eee;
`;
const PickerPanelWrapper = styled.div `
  position: absolute;
  z-index: 2;
  box-shadow: 0px 2px 10px #999999;
  margin-left: 2px;
`;
const checkSingleCell = (selectedRange, merges = []) => {
    if (!selectedRange) {
        return false;
    }
    if (selectedRange[0][0] === selectedRange[1][0] &&
        selectedRange[0][1] === selectedRange[1][1]) {
        return true;
    }
    return merges.some(([[msri, msci], [meri, meci]]) => msri === selectedRange[0][0] &&
        msci === selectedRange[0][1] &&
        meri === selectedRange[1][0] &&
        meci === selectedRange[1][1]);
};
export default ({ selectedRange, borderType, setBorderType, borderStyle, borderColor, setBorderStyle, setBorderColor, }) => {
    const merges = useSelector((state) => state.present.merges);
    const dispatch = useDispatch();
    const lineEl = useRef(null);
    const colorPopperRef = useRef(null);
    const [lineOpen, setLineOpen] = useState(false);
    const colorEl = useRef(null);
    const [colorOpen, setColorOpen] = useState(false);
    const isSingleCell = useMemo(() => checkSingleCell(selectedRange, merges), [selectedRange, merges]);
    const handleBorderClick = (type) => {
        setBorderType(type);
        if (!selectedRange)
            return;
        dispatch(setCellsBorderStyle(selectedRange, type, [borderStyle, borderColor]));
    };
    const handleColorChange = (colorInfo) => {
        setBorderColor(colorInfo.hex);
        setColorOpen(false);
        if (!selectedRange || !borderType)
            return;
        dispatch(setCellsBorderStyle(selectedRange, borderType, [
            borderStyle,
            colorInfo.hex,
        ]));
    };
    const handleBorderStyleChange = (type) => {
        setBorderStyle(type);
        setLineOpen(false);
        if (!selectedRange || !borderType)
            return;
        dispatch(setCellsBorderStyle(selectedRange, borderType, [type, borderColor]));
    };
    useClickAwayListener([colorPopperRef], () => setColorOpen(false));
    return (_jsxs(_Fragment, { children: [_jsxs(Layout, { children: [_jsxs(BorderTypeWrapper, { children: [_jsx(IconButton, { dense: true, onClick: () => handleBorderClick(BorderType.BORDER_ALL), children: _jsx(BorderAll, {}) }), _jsx(IconButton, { disabled: isSingleCell, dense: true, onClick: () => handleBorderClick(BorderType.BORDER_INNER), children: _jsx(BorderInner, {}) }), _jsx(IconButton, { disabled: isSingleCell, dense: true, onClick: () => handleBorderClick(BorderType.BORDER_HORIZONTAL), children: _jsx(BorderHorizontal, {}) }), _jsx(IconButton, { disabled: isSingleCell, dense: true, onClick: () => handleBorderClick(BorderType.BORDER_VERTICAL), children: _jsx(BorderVertical, {}) }), _jsx(IconButton, { dense: true, onClick: () => handleBorderClick(BorderType.BORDER_OUTER), children: _jsx(BorderOuter, {}) }), _jsx(IconButton, { dense: true, onClick: () => handleBorderClick(BorderType.BORDER_LEFT), children: _jsx(BorderLeft, {}) }), _jsx(IconButton, { dense: true, onClick: () => handleBorderClick(BorderType.BORDER_TOP), children: _jsx(BorderTop, {}) }), _jsx(IconButton, { dense: true, onClick: () => handleBorderClick(BorderType.BORDER_RIGHT), children: _jsx(BorderRight, {}) }), _jsx(IconButton, { dense: true, onClick: () => handleBorderClick(BorderType.BORDER_BOTTOM), children: _jsx(BorderBottom, {}) }), _jsx(IconButton, { dense: true, onClick: () => handleBorderClick(BorderType.BORDER_CLEAR), children: _jsx(BorderClear, {}) })] }), _jsxs(BorderStyleWrapper, { children: [_jsx(IconButton, { dense: true, onClick: () => setColorOpen(true), ref: colorEl, children: _jsx(Edit, {}) }), _jsx(IconButton, { dense: true, onClick: () => {
                                    setLineOpen(true);
                                }, ref: lineEl, children: _jsx(PowerInput, {}) })] })] }), _jsx(Popper, { open: colorOpen, referenceElement: colorEl, placement: "bottom-start", ref: colorPopperRef, children: _jsx(PickerPanelWrapper, { children: _jsx(SketchPicker, { color: borderColor, onChange: handleColorChange, className: SECOND_LEVEL_MENU }) }) }), _jsxs(Menu, { open: lineOpen, referenceElement: lineEl, MenuListProps: { className: SECOND_LEVEL_MENU }, children: [_jsx(MenuListItem, { onClick: () => handleBorderStyleChange('thin'), children: _jsx(Line, {}) }), _jsx(MenuListItem, { onClick: () => handleBorderStyleChange('medium'), children: _jsx(Line, { strokeWidth: 2 }) }), _jsx(MenuListItem, { onClick: () => handleBorderStyleChange('thick'), children: _jsx(Line, { strokeWidth: 3 }) }), _jsx(MenuListItem, { onClick: () => handleBorderStyleChange('dashed'), children: _jsx(Line, { strokeDasharray: 2 }) }), _jsx(MenuListItem, { onClick: () => handleBorderStyleChange('dotted'), children: _jsx(Line, { strokeDasharray: 1 }) })] })] }));
};
