import { jsx as _jsx } from "react/jsx-runtime";
import React, { useState } from 'react';
import { useDispatch, useSelector, useStore } from 'react-redux';
import { EDITOR_CHANGE, eventbus } from '../../constants';
import CustomEditor from '../../utils/CustomEditor';
import getCellValue from '../../utils/getCellValue';
import setCellTextStyleHelper from '../../utils/setCellTextStyleHelper';
import useWatchProp from '../../utils/useWatchProp';
import useListenEvent from '../useEventListener';
/**
 * 获取选中区域的字体字号
 * @param state
 * @param selectedRange
 * @param initValue
 * @returns
 */
const getSelectedFontSize = (state, selectedRange, initValue) => {
    const currentCellValue = getCellValue(state, selectedRange[0][0], selectedRange[0][1]);
    const isAllHasStyle = currentCellValue.every((element) => element.children.every((textItem) => textItem.fontSize));
    return isAllHasStyle ? currentCellValue[0].children[0].fontSize : initValue;
};
const FONT_SIZE_ITEMS = [12, 14, 16, 18, 20, 22, 24, 26, 28, 36, 48, 72];
/**
 * 字号选择按钮组件
 * @param props
 * @returns
 */
function FontSizeSelectButton(props) {
    const { editor = {}, selectedRange, editingCell } = props;
    const initValue = '16';
    const [value, setValue] = useState(initValue);
    const dispatch = useDispatch();
    const state = useStore().getState().present;
    const rows = useSelector((reduxState) => reduxState.present.rows);
    const merges = useSelector((reduxState) => reduxState.present.merges);
    useWatchProp(selectedRange, () => {
        if (selectedRange) {
            setValue(getSelectedFontSize(state, selectedRange, initValue));
        }
    });
    useListenEvent(eventbus, EDITOR_CHANGE, (currentEditor) => {
        setValue(CustomEditor.getFontSize(currentEditor) ?? initValue);
    });
    const handleChange = (event) => {
        setValue(event.target.value);
        setCellTextStyleHelper(editor, dispatch, 'fontSize', event.target.value, rows, merges, selectedRange, editingCell);
    };
    return (_jsx("select", { value: value, onChange: handleChange, children: FONT_SIZE_ITEMS.map((size) => (_jsx("option", { value: size, children: size }, size))) }));
}
export default React.memo(FontSizeSelectButton);
