import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
/* eslint-disable no-nested-ternary */
/* eslint-disable jsx-a11y/no-noninteractive-element-interactions */
import { useCallback, useEffect, useMemo, useRef } from 'react';
import classnames from 'classnames';
import styled from 'styled-components';
import { useDispatch, useSelector } from 'react-redux';
import { DEFAULT_CELL_WIDTH } from '@sinoform/print-out-core';
import { changeColWidth } from '../reducer';
import { transformCMToPxByConfig } from './util';
import drawRange from './drawRange';
const MarkLine = styled.div `
  position: absolute;
  z-index: 2;
  user-select: none;
`;
export default function THead({ selectedRange, }) {
    const printConfig = useSelector((state) => state.present);
    const dispatch = useDispatch();
    const { len } = printConfig.cols;
    const theadRef = useRef(null);
    const dragCellIdxRef = useRef();
    // 拖拽后宽度改变
    const colWidth = useSelector((state) => {
        const { cols } = state.present;
        let sum = 0;
        for (let i = 0; i < cols.len; i += 1) {
            sum += cols[i]?.width ?? DEFAULT_CELL_WIDTH;
        }
        return sum;
    });
    const verticalMarkLineRef = useRef(null);
    const markLineOffsetLeft = useMemo(() => transformCMToPxByConfig(printConfig.config, 'v') + 50, [printConfig.config]);
    const drawMarkLine = useCallback(() => {
        if (!verticalMarkLineRef.current)
            return;
        const tds = theadRef.current.querySelectorAll('th');
        const sum = markLineOffsetLeft + tds[0].offsetLeft;
        verticalMarkLineRef.current.style.left = `${sum}px`;
        verticalMarkLineRef.current.style.top = `0px`;
        verticalMarkLineRef.current.style.width = '1px';
        verticalMarkLineRef.current.style.height = '100%';
        verticalMarkLineRef.current.style.borderLeft = '1px solid #4b89ff';
    }, [markLineOffsetLeft]);
    useEffect(() => {
        drawMarkLine();
    }, [drawMarkLine]);
    useEffect(() => {
        if (selectedRange) {
            drawRange(selectedRange[0], selectedRange[1]);
        }
    }, [selectedRange, colWidth]);
    const isColInSelectedRange = (colIdx) => {
        if (!selectedRange)
            return false;
        return selectedRange[0][1] <= colIdx && colIdx <= selectedRange[1][1];
    };
    const handleMouseMoveInDocument = (event) => {
        const rightLine = document.querySelector('.sinoui-drag-right-line');
        if (theadRef.current && rightLine && rightLine.style.display === 'block') {
            const { left } = theadRef.current.getBoundingClientRect();
            rightLine.style.left = `${event.clientX - left}px`;
        }
    };
    const handleMouseUpInDocument = (event) => {
        const leftLine = document.querySelector('.sinoui-drag-left-line');
        const rightLine = document.querySelector('.sinoui-drag-right-line');
        if (theadRef.current &&
            dragCellIdxRef.current &&
            leftLine &&
            leftLine.style.display === 'block' &&
            rightLine &&
            rightLine.style.display === 'block') {
            leftLine.style.display = 'none';
            rightLine.style.display = 'none';
            const { left } = theadRef.current.getBoundingClientRect();
            const dragCell = theadRef.current.querySelectorAll('th')[dragCellIdxRef.current];
            const width = event.clientX - dragCell.offsetLeft - left > 0
                ? event.clientX - dragCell.offsetLeft - left >= 10
                    ? event.clientX - dragCell.offsetLeft - left
                    : 10
                : 10;
            dispatch(changeColWidth(dragCellIdxRef.current - 1, width));
        }
        document.removeEventListener('mousemove', handleMouseMoveInDocument, false);
        document.removeEventListener('mouseup', handleMouseUpInDocument, false);
    };
    const handleMouseMoveInThead = (event) => {
        const cell = event.target;
        const { left } = theadRef.current.getBoundingClientRect();
        // 如果当前鼠标位置大于单元格宽段-5 且当前鼠标放在表头
        if (event.clientX - left >= cell.offsetWidth + cell.offsetLeft - 5 &&
            cell.tagName === 'TH' &&
            cell.cellIndex !== 0) {
            // 设置鼠标样式
            cell.style.cursor = 'col-resize';
        }
        else {
            cell.style.cursor = 'default';
        }
    };
    const handleMouseDown = (event) => {
        const cell = event.target;
        const { left } = theadRef.current.getBoundingClientRect();
        const leftLine = document.querySelector('.sinoui-drag-left-line');
        const rightLine = document.querySelector('.sinoui-drag-right-line');
        if (event.clientX - left >= cell.offsetWidth + cell.offsetLeft - 5 &&
            cell.tagName === 'TH' &&
            cell.cellIndex !== 0) {
            // 处理拖拽改变列宽
            dragCellIdxRef.current = cell.cellIndex;
            // 显示辅助线
            if (leftLine && leftLine.style.display !== 'block') {
                leftLine.style.display = 'block';
                leftLine.style.left = `${cell.offsetLeft}px`;
            }
            if (rightLine && rightLine.style.display !== 'block') {
                rightLine.style.display = 'block';
                rightLine.style.left = `${cell.offsetLeft + cell.clientWidth}px`;
            }
            document.addEventListener('mousemove', handleMouseMoveInDocument, false);
            document.addEventListener('mouseup', handleMouseUpInDocument, false);
        }
        // else {
        //   // 处理选中整列
        //   const colId = parseInt(cell.dataset?.colid!, 10);
        //   drawRange([0, colId], [printConfig.rows.len - 1, colId]);
        //   selectStartCellRef.current = colId;
        //   document.addEventListener('mousemove', handleMouseMoveForSelect, false);
        //   document.addEventListener('mouseup', handleMouseUpForSelect, false);
        // }
    };
    return (_jsxs(_Fragment, { children: [_jsx("thead", { ref: theadRef, className: "custom-print-table-row-header", onMouseMove: handleMouseMoveInThead, onMouseDown: handleMouseDown, children: _jsxs("tr", { children: [_jsx("th", { children: _jsx("div", {}) }), Array.from({ length: len }).map((_item, idx) => {
                            const str = String.fromCharCode(idx + 65);
                            return (_jsx("th", { className: classnames({
                                    'col-in-selected-range': isColInSelectedRange(idx),
                                }), id: `table-col-header-${idx}`, "data-colid": idx, children: str }, idx));
                        })] }) }), _jsx(MarkLine, { ref: verticalMarkLineRef, "data-markline": true })] }));
}
