/**
 * 校验复制的区域粘贴到目标区域之后是否超出了单元格边界
 * @param sourceRange
 * @param targetPos
 * @param draft
 */
export const canPastCell = (sourceRange, targetPos, draft) => {
    const { rows, cols } = draft;
    const [tri, tci] = targetPos;
    const [[sri, sci], [eri, eci]] = sourceRange;
    return tri + eri - sri < rows.len && tci + eci - sci < cols.len;
};
/**
 * 目标位置对应的区域是否满足源选中区域的单元格粘贴的条件
 *
 * 即对应区域的单元格是否有合并的单元格超出边界的情况
 *
 * @param sourceRange 源选中单元格区域
 * @param targetPos   目标位置
 * @param draft       当前布局状态
 */
export const checkCellRange = (targetPos, sourceRange, merges = []) => {
    const [[sri, sci], [eri, eci]] = sourceRange;
    // 计算出对应的目标单元格区域
    const [tsri, tsci] = targetPos;
    const teri = tsri + eri - sri;
    const teci = tsci + eci - sci;
    return !merges.some(([[msri, msci], [meri, meci]]) => 
    // 上方的单元格被合并超出上边界
    (msri < tsri && meri >= tsri && msci > tsci && msci <= teci) ||
        // 左方的单元格被合并超出左边界
        (msci < tsci && meci >= tsci && msri > tsri && msri <= teri) ||
        // 下方的单元格被合并并超出下边界
        (msri <= teri && meri > teri && msci >= tsci && msci <= teci) ||
        // 右方的单元格被合并并超出右边界
        (msci <= teci && meci > teci && msri >= tsri && msri <= teri));
};
