import { PrintConfig } from 'packages/types/src/print-layout';
import { BorderType } from '../constants';
import { ActionType, ChangeColWidthAction, ChangeRowHeightAction, CopyCellAction, DeleteColAction, InsertColAction, MergeCellAction, InsertRowAction, DeleteRowAction, CellPos, CellRange, CutCellAction, SetCellsBorderAction, SetCellsStyleAction } from './types';
/**
 * 合并或拆分单元格
 *
 * 如果选中的单元格中含有被合并的单元格，执行拆分动作，拆分选中区域内所有的被合并的单元格，否则执行合并操作
 *
 * 前提：确保选中单元格的边界是完整的单元格，不能出现被合并的单元格一部分再选中区域内，一部分在选中区域外的情况
 *
 * @param fromCell 选中单元格的起始位置
 * @param toCell   选中单元格的结束位置
 * @returns
 */
export declare function mergeCells(fromCell: [number, number], toCell: [number, number]): MergeCellAction;
/**
 * 拖动改变行高
 * @param rowIdx
 * @param height
 * @returns
 */
export declare function changeRowHeight(rowIdx: number, height: number): ChangeRowHeightAction;
/**
 * 拖动改变列宽
 * @param colIdx
 * @param width
 * @returns
 */
export declare function changeColWidth(colIdx: number, width: number): ChangeColWidthAction;
/**
 * 新增行
 * @param rowIdx
 * @returns
 */
export declare function insertRow(rowIdx: number): InsertRowAction;
/**
 * 删除行
 * @param from
 * @param len
 * @returns
 */
export declare function deleteRow(from: number, len: number): DeleteRowAction;
/**
 * 新增列
 * @param colIdx
 * @returns
 */
export declare function insertCol(colIdx: number): InsertColAction;
/**
 * 删除选中的列
 * @param startCol  选中单元格的起始列
 * @param endCol    选中单元格的结束列
 */
export declare function deleteCol(startCol: number, endCol: number): DeleteColAction;
/**
 * 单元格复制
 *
 * @param source 选中的单元格起始和结束位置
 * @param target 目标单元格位置
 * @returns
 */
export declare function copyCell(source: CellRange, target: CellPos): CopyCellAction;
export declare function cutCell(source: CellRange, target: CellPos): CutCellAction;
export declare function setPrintConfig(config: PrintConfig): {
    type: ActionType;
    payload: PrintConfig;
};
export declare function setCellsBorderStyle(range: CellRange, type: BorderType, style?: any): SetCellsBorderAction;
export declare function setCellsStyle(cells: CellPos[], style: {
    [x: string]: string;
}): SetCellsStyleAction;
