"use strict";

var _interopRequireDefault = /*#__PURE__*/require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = checkConfigIsOutRange;
var _isEqual = /*#__PURE__*/_interopRequireDefault( /*#__PURE__*/require("lodash-es/isEqual"));
var _printOutCore = /*#__PURE__*/require("@sinoform/print-out-core");
/**
 * 校验是否有单元格超出了设置的页面边距
 * @param customPrintConfig 自定义布局配置信息
 * @returns
 */
function checkConfigIsOutRange(customPrintConfig) {
  if (!customPrintConfig) {
    return false;
  }
  var rows = customPrintConfig.rows,
    cols = customPrintConfig.cols,
    _customPrintConfig$co = customPrintConfig.config,
    config = _customPrintConfig$co === void 0 ? {} : _customPrintConfig$co;
  var pageConfig = config.pageConfig;
  var pageDir = pageConfig.pageDir,
    pageSize = pageConfig.pageSize,
    pagePaddingLeft = pageConfig.pagePaddingLeft,
    pagePaddingRight = pageConfig.pagePaddingRight;
  var paddingLeft = parseFloat(pagePaddingLeft);
  var paddingRight = parseFloat(pagePaddingRight);
  var pageWidth = (0, _printOutCore.mmToPx)(_printOutCore.PAGE_SIZE_CONFIG[pageSize]['v'][pageDir === '纵向' ? 0 : 1] - (paddingLeft + paddingRight));
  var maxCol = (0, _printOutCore.getMaxColLenInPageConfig)(pageWidth, cols);
  for (var i = 0; i < rows.len; i += 1) {
    for (var j = 0; j < cols.len; j += 1) {
      var _rows$i, _rows$i$cells;
      if ((_rows$i = rows[i]) !== null && _rows$i !== void 0 && (_rows$i$cells = _rows$i.cells) !== null && _rows$i$cells !== void 0 && _rows$i$cells[j]) {
        var _rows$i$cells$j = rows[i].cells[j],
          value = _rows$i$cells$j.value,
          _rows$i$cells$j$merge = _rows$i$cells$j.merge,
          merge = _rows$i$cells$j$merge === void 0 ? [0, 0] : _rows$i$cells$j$merge;
        // 分两种场景的超出
        // 1. 合并单元格的起始位置未超出，但是结束位置超出
        // 2. 非合并的单元格位置位置超出，且单元格内容不为空
        if (j < maxCol && j + merge[1] >= maxCol || value && !(0, _isEqual.default)(value, _printOutCore.DEFAULT_CELL_VALUE) && j >= maxCol) {
          return true;
        }
      }
    }
  }
  return false;
}